@@ -26,3 +26,6 @@ class ObjectPermissionBackend(object):
     
     def has_perm(self, user, perm, obj=None):
         return has_perm(perm, user, obj)
+    
+    def has_module_perms(self, user, app_label):
+        return has_perm(app_label, user)
